@@ -1,6 +1,6 @@
 package PerlPowerTools;
 
-our $VERSION = '1.003';
+our $VERSION = '1.007_01';
 
 1;
 
@@ -17,8 +17,10 @@ BSD utilities.
 
 =head1 DESCRIPTION
 
-
-Unix Reconstruction Project
+The Unix Reconstruction Project. By default, these install into the
+F<~/perlpowertools> directory. You'll probably need to add that directory
+to C<PATH> to use them. You can install them anywhere you like by
+setting C<INSTALL_BASE> when you run F<Makefile.PL>.
 
 =head2 Utilities
 
@@ -234,7 +236,7 @@ Unix Reconstruction Project
 
 =item unpar - extract files from a Perl archive
 
-=item unshar - extract files from a shell archive 
+=item unshar - extract files from a shell archive
 
 =item uudecode, uuencode - encode/decode a binary file
 
@@ -263,18 +265,17 @@ Unix Reconstruction Project
 
 This source is in Github:
 
-	https://github.com/briandfoy/ppt
+	https://github.com/briandfoy/PerlPowerTools
 
 =head1 AUTHOR
 
 brian d foy, C<< <bdfoy@cpan.org> >> is the current maintainer, even
-though he write none of the utilities.
-
-
+though he wrote none of the utilities.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2004-2014 brian d foy.  All rights reserved.
+Copyright (c) 2004-2014 by various authors.  See each program for
+specific information.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
